==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OperationResponseAssignmentOperation.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OperationResponseAssignmentOperationConfiguration;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperation
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperation.JSON_PROPERTY_CONFIGURATION })
@JsonTypeName("OperationResponse_assignmentOperation")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OperationResponseAssignmentOperation implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private OperationResponseAssignmentOperationConfiguration _configuration;

    public OperationResponseAssignmentOperation() {
    }

    public OperationResponseAssignmentOperation _configuration(
            OperationResponseAssignmentOperationConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OperationResponseAssignmentOperationConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(OperationResponseAssignmentOperationConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperation operationResponseAssignmentOperation = (OperationResponseAssignmentOperation) o;
        return Objects.equals(this._configuration, operationResponseAssignmentOperation._configuration);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_configuration);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperation {\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/OperationResponseAssignmentOperation.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OperationResponseAssignmentOperationConfiguration;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OperationResponseAssignmentOperation
 */
@JsonPropertyOrder({ OperationResponseAssignmentOperation.JSON_PROPERTY_CONFIGURATION })
@JsonTypeName("OperationResponse_assignmentOperation")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OperationResponseAssignmentOperation implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONFIGURATION = "configuration";
    private OperationResponseAssignmentOperationConfiguration _configuration;

    public OperationResponseAssignmentOperation() {
    }

    public OperationResponseAssignmentOperation _configuration(
            OperationResponseAssignmentOperationConfiguration _configuration) {

        this._configuration = _configuration;
        return this;
    }

    /**
     * Get _configuration
     *
     * @return _configuration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OperationResponseAssignmentOperationConfiguration getConfiguration() {
        return _configuration;
    }

    @JsonProperty(JSON_PROPERTY_CONFIGURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConfiguration(OperationResponseAssignmentOperationConfiguration _configuration) {
        this._configuration = _configuration;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OperationResponseAssignmentOperation operationResponseAssignmentOperation = (OperationResponseAssignmentOperation) o;
        return Objects.equals(this._configuration, operationResponseAssignmentOperation._configuration);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_configuration);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OperationResponseAssignmentOperation {\n");
        sb.append("    _configuration: ").append(toIndentedString(_configuration)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
